@@ -1,9 +1,10 @@
 import time
 import random
+import uuid
 import win32clipboard
 import win32con
 import webbrowser
-from subprocess import getstatusoutput
+from subprocess import Popen
 from xyw_macro.win32 import send_kb_event, send_unicode
 from xyw_macro.hook import VK
 
@@ -68,7 +69,7 @@ def run_cmd(cmd):
     :param cmd:
     :return:
     """
-    return getstatusoutput(cmd)
+    Popen(cmd)
 
 
 def open_file(path):
@@ -77,7 +78,7 @@ def open_file(path):
     :param path:
     :return:
     """
-    return getstatusoutput('explorer.exe %s' % path)
+    Popen('explorer.exe %s' % path)
 
 
 def input_chars(chars):
@@ -104,13 +105,46 @@ def open_url(url, browser_path=None):
         webbrowser.open(url, new=0, autoraise=True)
 
 
+def get_mac():
+    """
+    获取本机mac地址（单网卡）
+    :return: 12位mac地址
+    """
+    mac = uuid.uuid1().hex[-12:].upper()
+    tem = [mac[i * 2: i * 2 + 2] for i in range(len(mac) // 2)]
+    mac = '-'.join(tem)
+    return mac
+
+
+def confirm_mac(mac):
+    """
+    验证所给mac地址是否与本机匹配
+    :param mac:
+    :return:
+    """
+    if isinstance(mac, str):
+        return mac.upper() == get_mac()
+    elif isinstance(mac, (list, tuple)):
+        local_mac = get_mac()
+        for item in mac:
+            if item.upper() == local_mac:
+                return True
+        return False
+    else:
+        raise TypeError('param mac must be string or list')
+
+
 if __name__ == '__main__':
     # print(random_sleep(0.2, 0.25))
     # print(get_clipboard_files())
     # print(type(get_clipboard_files()))
     # press_copy()
     # print(run_cmd(r"C:\Program Files (x86)\Thunder Network\Thunder\Program\ThunderStart.exe"))
-    # print(open_file('xue'))
+    # print(open_file('hook.py'))
     # input_chars('今天是个好人797987/*/-*-*+')
     # open_url('www.baidu.com', r"C:\Program Files (x86)\Microsoft\Edge\Application\msedge.exe")
-    open_url('www.baidu.com')
+    # open_url('www.baidu.com')
+    # print(run_cmd(r"D:\Program Files (x86)\Everything\Everything.exe"))
+    # print(run_cmd(r"C:\Program Files (x86)\WXWork\WXWork.exe"))
+    # print(get_mac())
+    print(confirm_mac('0C-9D-92-0F-42-6E'))
