@@ -447,6 +447,7 @@ class Core(metaclass=SingletonType):
 
         self.__flag_run = False
         self.__flag_start = False
+        self.__repeat_key = None
 
     def add_window(self, window):
         """
@@ -525,6 +526,9 @@ class Core(metaclass=SingletonType):
 
         # 判断是否有命令正在执行中
         if self.__flag_run:
+            if event.vk_code == self.__repeat_key and HookConstants.is_keyup(event.w_param):
+                self.__repeat_key = None
+                return 1
             self.__show_message('执行中,\n请等待!')
             return 1
 
@@ -542,13 +546,15 @@ class Core(metaclass=SingletonType):
             return 0
 
         # 判断按键是否触发相关命令函数
-        inspect_flag = False
+        # inspect_flag = False
         for command in config.commands.values():
             if command.condition.inspect(event):
                 if command.condition.alias is None:
                     self.__show_message('命令\n{}'.format(ID(command.condition.vk)))
                 else:
                     self.__show_message('命令\n{}'.format(command.condition.alias))
+                if command.condition.repeat:
+                    self.__repeat_key = event.vk_code
 
                 def callback():
                     self.__flag_run = True
@@ -560,9 +566,11 @@ class Core(metaclass=SingletonType):
                     self.__flag_run = False
 
                 self.__pool.submit(callback)
-                inspect_flag = True
-                break
-        if (not inspect_flag) and HookConstants.is_keyup(event.w_param):
+                # inspect_flag = True
+                return 1
+            elif command.condition.vk == event.vk_code and HookConstants.is_keyup(event.w_param):
+                return 1
+        if HookConstants.is_keyup(event.w_param):
             self.__show_message('命令\n空')
         return 1
 
